@@ -17,18 +17,35 @@
 # You should have received a copy of the GNU General Public License
 # along with diffusr. If not, see <http://www.gnu.org/licenses/>.
 
+
 #' Graph diffusion using a Markov random walk
 #'
-#' @description A Markov Random Walk takes an inital distribution \code{p0} and calculates the stationary distribution of that.
-#' The diffusion process is regulated by a restart probability \code{r} which controls how often the MRW jumps back to the initial values.
+#' @description A Markov Random Walk takes an inital distribution \code{p0}
+#' and calculates the stationary distribution of that.
+#' The diffusion process is regulated by a restart probability \code{r} which
+#' controls how often the MRW jumps back to the initial values.
 #'
 #' @export
 #' @docType methods
 #' @rdname random-walk-methods
 #'
-#' @param p0  an \code{n}-dimensional numeric non-negative vector representing the starting distribution of the Markov chain (does not need to sum to one)
-#' @param graph  an (\code{n x n})-dimensional numeric non-negative adjacence matrix representing the graph
-#' @param r  a scalar between (0, 1). restart probability if a Markov random walk with restart is desired
+#' @param p0  an \code{n x p}-dimensional numeric non-negative vector/matrix
+#'  representing the starting distribution of the Markov chain
+#'  (does not need to sum to one).
+#' @param graph  an (\code{n x n})-dimensional numeric non-negative adjacence
+#' matrix representing the graph
+#' @param r  a scalar between (0, 1). restart probability if a Markov random
+#' walk with restart is desired
+#' @param thresh  threshold for breaking the iterative computation of the
+#'  stationary distribution. If the absolute difference of the distribution at
+#'  time point $t-1$ and $t$ is less than \code{thresh}, then the algorithm stops.
+#'  If \code{thresh} is not reached before \code{niter}, then the algorithm stops
+#'  as well.
+#' @param niter  maximal number of iterations for computation of the
+#'  Markov chain. If \code{thresh} is not reached, then \code{niter} is used as
+#' stop criterion.
+#' @param do.analytical  boolean if the stationary distribution shall be
+#'  computed solving the analytical solution or rather iteratively
 #' @param ...  additional parameters
 #' @return  returns the stationary distribution as numeric vector
 #'
@@ -50,35 +67,50 @@
 #' pt    <- random.walk(p0, graph)
 setGeneric(
   "random.walk",
-  function(p0, graph, r=.5, ...)
+  function(p0, graph, r=.5, niter=1e4, thresh=1e-4, do.analytical=FALSE, ...)
   {
     standardGeneric("random.walk")
   },
   package="diffusr"
 )
 
-
 #' @rdname random-walk-methods
 #' @aliases random.walk,numeric,matrix-method
 setMethod(
   "random.walk",
   signature = signature(p0="numeric", graph="matrix"),
-  function(p0, graph, r=.5, ...)
+  function(p0, graph, r=.5, niter=1e4, thresh=1e-4, do.analytical=FALSE, ...)
+  {
+    p0 <- as.matrix(p0, ncol=1)
+    random.walk(p0, graph, r, niter, thresh, do.analytical, ...)
+  }
+)
+
+#' @rdname random-walk-methods
+#' @aliases random.walk,matrix,matrix-method
+setMethod(
+  "random.walk",
+  signature = signature(p0="matrix", graph="matrix"),
+  function(p0, graph, r=.5, niter=1e4, thresh=1e-4, do.analytical=FALSE, ...)
   {
     stopifnot(length(r) == 1)
     .check.restart(r)
-    .check.vector(p0)
+    .check.starting.matrix(p0)
     .check.graph(graph, p0)
+
     if (any(diag(graph) != 0))
     {
       message("setting diag of graph to zero")
       diag(graph) <- 0
     }
+
     stoch.graph <- normalize.stochastic(graph)
     if(!.is.ergodic(stoch.graph))
-      stop("the provided graph has more than one component. It is likely not ergodic.")
-    invisible(mrwr_(normalize.stochastic(p0),
-                    stoch.graph,
-                    r))
+      stop(paste("the provided graph has more than one component.",
+                 "It is likely not ergodic."))
+
+    invisible(
+      mrwr_(normalize.stochastic(p0),
+            stoch.graph, r, thresh, niter, do.analytical))
   }
 )
